@@ -115,6 +115,10 @@ class KnowledgeCard(BaseModel):
     source_indexes: Optional[List[KnowledgeSearchSourceIndex]] = Field(
         description="The source indexes of the knowledge card",
     )
+    card_type: str | None = Field(
+        description="The type of card",
+        examples=["company", "chart", "table", "text"],
+    )
 
 
 class KnowledgeSearchOutputs(BaseModel):
